Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(293)

Unified Diff: content/common/frame_replication_state.h

Issue 2046733003: Replicate WebInsecureRequestPolicy instead of a bool for strict mixed content checks. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@securitycontext
Patch Set: alexmos@ Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/frame_messages.h ('k') | content/common/frame_replication_state.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/frame_replication_state.h
diff --git a/content/common/frame_replication_state.h b/content/common/frame_replication_state.h
index 9cb88af432b95953bd2fc6d1b1a5ef9c34911510..b3d3544d6a688ecb4af9f00286209337e79f613a 100644
--- a/content/common/frame_replication_state.h
+++ b/content/common/frame_replication_state.h
@@ -10,6 +10,7 @@
#include "content/common/content_export.h"
#include "content/common/content_security_policy_header.h"
+#include "third_party/WebKit/public/platform/WebInsecureRequestPolicy.h"
#include "url/origin.h"
namespace blink {
@@ -27,7 +28,7 @@ struct CONTENT_EXPORT FrameReplicationState {
const std::string& name,
const std::string& unique_name,
blink::WebSandboxFlags sandbox_flags,
- bool should_enforce_strict_mixed_content_checking,
+ blink::WebInsecureRequestPolicy insecure_request_policy,
bool has_potentially_trustworthy_unique_origin);
FrameReplicationState(const FrameReplicationState& other);
~FrameReplicationState();
@@ -95,10 +96,10 @@ struct CONTENT_EXPORT FrameReplicationState {
// operator.
blink::WebTreeScopeType scope;
- // True if a frame's current document should strictly block all mixed
- // content. Updates are immediately sent to all frame proxies when
- // frames live in different processes.
- bool should_enforce_strict_mixed_content_checking;
+ // The insecure request policy that a frame's current document is enforcing.
+ // Updates are immediately sent to all frame proxies when frames live in
+ // different processes.
+ blink::WebInsecureRequestPolicy insecure_request_policy;
// True if a frame's origin is unique and should be considered potentially
// trustworthy.
« no previous file with comments | « content/common/frame_messages.h ('k') | content/common/frame_replication_state.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698